Collection of algorithms.
Modules
- components
- Components related algorithms, including connectivity, cuts, etc.
- cycles
- Cycles related algorithms, including testing if a graph is acyclic.
- degrees
- Test if a graph is regular, find minimum and maximum degrees, etc.
- distances
- kruskal
- Kruskal’s minimum spanning tree algorithm.
- paths
- Paths related algorithms, including find path between two vertices.
- prim
- Prim’s minimum spanning tree algorithm.
- sets
- Iterators for edge and vertex set complements.
- trees
- Trees related algortihms, including testing if a graph is a tree.