pub struct StaticDirectedEdge<N>(/* private fields */)
where
N: Num;Trait Implementations
Sourceimpl<N> Bounded for StaticDirectedEdge<N>where
N: Num,
impl<N> Bounded for StaticDirectedEdge<N>where
N: Num,
Sourcefn max_value() -> StaticDirectedEdge<N>
fn max_value() -> StaticDirectedEdge<N>
Returns the largest finite number this type can represent
Sourcefn min_value() -> StaticDirectedEdge<N>
fn min_value() -> StaticDirectedEdge<N>
Returns the smallest finite number this type can represent
Sourceimpl<N> Clone for StaticDirectedEdge<N>
impl<N> Clone for StaticDirectedEdge<N>
Sourcefn clone(&self) -> StaticDirectedEdge<N>
fn clone(&self) -> StaticDirectedEdge<N>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<N> Debug for StaticDirectedEdge<N>
impl<N> Debug for StaticDirectedEdge<N>
Sourceimpl<N> Hash for StaticDirectedEdge<N>
impl<N> Hash for StaticDirectedEdge<N>
Sourceimpl<N> Ord for StaticDirectedEdge<N>
impl<N> Ord for StaticDirectedEdge<N>
Sourcefn cmp(&self, other: &StaticDirectedEdge<N>) -> Ordering
fn cmp(&self, other: &StaticDirectedEdge<N>) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<N> PartialEq for StaticDirectedEdge<N>
impl<N> PartialEq for StaticDirectedEdge<N>
Sourceimpl<N> PartialOrd for StaticDirectedEdge<N>where
N: PartialOrd + Num,
impl<N> PartialOrd for StaticDirectedEdge<N>where
N: PartialOrd + Num,
impl<N> Copy for StaticDirectedEdge<N>
impl<N> Eq for StaticDirectedEdge<N>
impl<N> StructuralPartialEq for StaticDirectedEdge<N>where
N: Num,